From 65cda55e40ac74e77bbf795571d5ac7c7e261ed3 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?J=C3=B6rn=20K=C3=BCnsem=C3=B6ller?=
 <jkuensem@physik.uni-bielefeld.de>
Date: Fri, 26 Mar 2021 17:21:39 +0100
Subject: [PATCH] TMSS-520: annotate period category for clarity

---
 SAS/TMSS/backend/src/tmss/tmssapp/models/specification.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/SAS/TMSS/backend/src/tmss/tmssapp/models/specification.py b/SAS/TMSS/backend/src/tmss/tmssapp/models/specification.py
index 9645087251c..b8ba52fc92f 100644
--- a/SAS/TMSS/backend/src/tmss/tmssapp/models/specification.py
+++ b/SAS/TMSS/backend/src/tmss/tmssapp/models/specification.py
@@ -116,7 +116,7 @@ class Quantity(AbstractChoice):
 
 
 class PeriodCategory(AbstractChoice):
     """Defines the model and predefined list of possible period categories to be used in Project.
         The items in the Choices class below are automagically populated into the database via a data migration."""
 
     class Choices(Enum):
@@ -305,8 +305,8 @@ class Project(NamedCommonPK):
     private_data = BooleanField(default=True, help_text='True if data of this project is sensitive. Sensitive data is not made public.')
     expert = BooleanField(default=False, help_text='Expert projects put more responsibility on the PI.')
     filler = BooleanField(default=False, help_text='Use this project to fill up idle telescope time.')
-    project_category = ForeignKey('ProjectCategory', null=True, on_delete=PROTECT, help_text='Project category.')
-    period_category = ForeignKey('PeriodCategory', null=True, on_delete=PROTECT, help_text='Period category.')
+    project_category = ForeignKey('ProjectCategory', help_text='Category this project falls under.', null=True, on_delete=PROTECT, help_text='Project category.')
+    period_category = ForeignKey('PeriodCategory', help_text='Policy for managing the lifetime of this project.', null=True, on_delete=PROTECT, help_text='Period category.')
     auto_pin = BooleanField(default=False, help_text='True if the output_pinned flag of tasks in this project should be set True on creation.')
     path_to_project = "project"
 
@@ -116,7 +116,7 @@ class Quantity(AbstractChoice):
 
 class PeriodCategory(AbstractChoice):
-    """Defines the model and predefined list of possible period categories to be used in Project.
+    """Defines the model and predefined list of possible period categories to be used in Project as a policy for managing the project's lifetime.
         The items in the Choices class below are automagically populated into the database via a data migration."""
 
-- 
GitLab